@@ -54,22 +54,24 @@ def img_get_exif(fn):
     data = get_exif('img/2013-04-13 12.17.09.jpg')
     print data
     """
+
     ret = {}
     i = Image.open(fn)
-    info = i._getexif()
-    try:
-        for tag, value in info.items():
-            decoded = TAGS.get(tag, tag)
-            ret[decoded] = value
-    except:
-        now = datetime.now()
-        ret['DateTimeOriginal'] = now.strftime("%Y:%m:%d %H:%M:%S")
+    if hasattr(i, '_getexif'):
+        info = i._getexif()
+        try:
+            for tag, value in info.items():
+                decoded = TAGS.get(tag, tag)
+                ret[decoded] = value
+        except:
+            now = datetime.now()
+            ret['DateTimeOriginal'] = now.strftime("%Y:%m:%d %H:%M:%S")
 
-    try:
-        str(ret['DateTimeOriginal'])
-    except:
-        now = datetime.now()
-        ret['DateTimeOriginal'] = now.strftime("%Y:%m:%d %H:%M:%S")
+        try:
+            str(ret['DateTimeOriginal'])
+        except:
+            now = datetime.now()
+            ret['DateTimeOriginal'] = now.strftime("%Y:%m:%d %H:%M:%S")
 
     return ret
 
@@ -191,7 +193,10 @@ def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend, client,
 
             # Reading EXIF Data
             data_image = img_get_exif(img)
-            capture_data = datetime.strptime(str(data_image['DateTimeOriginal']), "%Y:%m:%d %H:%M:%S")
+            try:
+                capture_data = datetime.strptime(str(data_image['DateTimeOriginal']), "%Y:%m:%d %H:%M:%S")
+            except:
+                capture_data = datetime.now()
 
             # Adding to database
             im = mymodels.Photo(image="uploads/photos/" + nombre_imagen,
